StampResult class
The outcome of stampBuildDirectory.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashedFileCount → int
-
Number of files included in the content hash.
final
- info → BuildInfo
-
The build metadata written to
version.json.final - reusedBuiltAt → bool
-
Whether the previous
builtAtwas kept because the content hash is unchanged (a no-op re-run).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
writtenFiles
→ List<
String> -
Paths (relative to the build directory) whose content changed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited